@@ -9,10 +9,9 @@ import shutil
 import argparse
 from .wasm_checker import check_import_section
 
-__version__ = "0.1.7"
+__version__ = "0.2.1"
 
-src_dir = os.path.dirname(__file__)
-cur_dir = os.path.abspath(os.curdir)
+src_dir = os.path.dirname(__file__).replace('\\', '/')
 
 
 #https://stackabuse.com/how-to-print-colored-text-in-python/
@@ -21,27 +20,14 @@ HEADER = '\033[95m'
 OKBLUE = '\033[94m'
 OKCYAN = '\033[96m'
 OKGREEN = '\033[92m'
-WARNING = '\033[1;30;43m'
+WARNING = '\033[1;33;40m'
 FAIL = '\033[91m'
 ENDC = '\033[0m'
 BOLD = '\033[1m'
 UNDERLINE = '\033[4m'
 
 def find_target_dir(lib_name):
-    parent_dir = os.path.dirname(cur_dir)
-    base_name = os.path.basename(cur_dir)
-    parent_toml_file = os.path.join(parent_dir, 'Cargo.toml')
-    try:
-        with open(parent_toml_file, 'r') as f:
-            cargo_toml = toml.loads(f.read())
-            members = cargo_toml['workspace']['members']
-            for member in members:
-                if base_name == member:
-                    return os.path.join(parent_dir, 'target', lib_name)
-    except FileNotFoundError:
-        return os.path.join(cur_dir, 'target')
-    except KeyError:
-        return os.path.join(cur_dir, 'target')
+    cur_dir = os.path.abspath(os.curdir)
     return os.path.join(cur_dir, 'target')
 
 def print_err(msg):
@@ -58,12 +44,13 @@ def run_builder():
     init.add_argument('project_name')
 
     build = subparsers.add_parser('build')
+    build.add_argument('--dir-name', default=".")
     build.add_argument(
         '-d', '--debug', action='store_true', help='set to true to enable debug build')
     build.add_argument(
         '-s', '--stack-size', default=8192, help='configure stack size')
 
-    result = parser.parse_args()
+    result, unknown = parser.parse_known_args()
     if not result:
         parser.print_usage()
         sys.exit(-1)
@@ -92,6 +79,8 @@ def run_builder():
             print_err(f'{FAIL}: {e}')
             sys.exit(-1)
     elif result.subparser == "build":
+        if result.dir_name:
+            os.chdir(result.dir_name)
         if result.debug:
             build_mode = ''
         else:
@@ -111,8 +100,10 @@ def run_builder():
                 sys.exit(-1)
             lib_name = project['lib']['name']
         target_dir = find_target_dir(lib_name)
+        target_dir = target_dir.replace('\\', '/')
         os.environ['RUSTFLAGS'] = f'-C link-arg=-zstack-size={result.stack_size} -Clinker-plugin-lto'
-        cmd = f'cargo +nightly build --target=wasm32-wasi --target-dir={target_dir} -Zbuild-std --no-default-features {build_mode} -Zbuild-std-features=panic_immediate_abort'
+        cmd = fr'cargo +nightly build --target=wasm32-wasi --target-dir={target_dir} -Zbuild-std --no-default-features {build_mode} -Zbuild-std-features=panic_immediate_abort'
+        print(cmd)
         cmd = shlex.split(cmd)
         ret_code = subprocess.call(cmd, stdout=sys.stdout, stderr=sys.stderr)
         if not ret_code == 0:
@@ -125,7 +116,7 @@ def run_builder():
             sys.exit(-1)
 
         if shutil.which('wasm-opt'):
-            cmd = f'wasm-opt {target_dir}/wasm32-wasi/release/{lib_name}.wasm -Oz --strip-debug -o {target_dir}/{lib_name}.wasm'
+            cmd = f'wasm-opt {target_dir}/wasm32-wasi/release/{lib_name}.wasm -O3 --strip-debug -o {target_dir}/{lib_name}.wasm'
             cmd = shlex.split(cmd)
             ret_code = subprocess.call(cmd, stdout=sys.stdout, stderr=sys.stderr)
             if not ret_code == 0:
@@ -145,9 +136,10 @@ There are ready-to-install packages for many platforms:
 
         try:
             temp_dir = tempfile.mkdtemp()
+            temp_dir = temp_dir.replace('\\', '/')
             with open(f'{src_dir}/templates/abigen/Cargo.toml', 'r') as f:
                 cargo_toml = f.read()
-                path_name = os.path.abspath(os.curdir)
+                path_name = os.path.abspath(os.curdir).replace('\\', '/')
                 cargo_toml = cargo_toml.format(package_name=package_name, path_name=path_name)
                 with open(f'{temp_dir}/Cargo.toml', 'w') as f:
                     f.write(cargo_toml)
@@ -160,12 +152,13 @@ There are ready-to-install packages for many platforms:
 
             del os.environ['RUSTFLAGS']
             cmd = f'cargo run --package abi-gen --manifest-path={temp_dir}/Cargo.toml --target-dir={target_dir} --release'
+            print(cmd)
             cmd = shlex.split(cmd)
             ret_code = subprocess.call(cmd, stdout=sys.stdout, stderr=sys.stderr)
             if not ret_code == 0:
                 sys.exit(ret_code)
         finally:
-            shutil.rmtree(temp_dir)
+           shutil.rmtree(temp_dir)
     else:
         parser.print_usage()
 
